@@ -134,21 +134,21 @@ function(object,
 		    tick = FALSE, labels = "")
 	
     if (length(X.label) > 1) {
-        text3d(cord.X[, 1] + 0.05, cord.X[, 2], cord.X[, 3] + 0.05, text = X.label,
+        text3d(cord.X[, 1] + 0.05, cord.X[, 2], cord.X[, 3] + 0.05, texts = X.label,
                color = col[[1]], font = font[1], cex = cex[1])
     }
 	
     if (length(Y.label) > 1) {
-        text3d(cord.Y[, 1] + 0.05, cord.Y[, 2], cord.Y[, 3] + 0.05, text = Y.label,
+        text3d(cord.Y[, 1] + 0.05, cord.Y[, 2], cord.Y[, 3] + 0.05, texts = Y.label,
                color = col[[2]], font = font[2], cex = cex[2])
     }
 	par3d(cex = 0.8)	
 	
     if (any(axes.box == "axes") || any(axes.box == "all")) { 
         if (any(label.axes.box == "axes") || any(label.axes.box == "both")) {	
-            text3d(1.2, -0.05, 0, text = xlab, cex = 0.8, color = "black")
-            text3d(0, 1.27, 0, text = ylab, cex = 0.8, color = "black")
-            text3d(0, -0.05, 1.2, text = zlab, cex = 0.8, color = "black")
+            text3d(1.2, -0.05, 0, texts = xlab, cex = 0.8, color = "black")
+            text3d(0, 1.27, 0, texts = ylab, cex = 0.8, color = "black")
+            text3d(0, -0.05, 1.2, texts = zlab, cex = 0.8, color = "black")
 		}
 		
         x =	c(1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09,  1.09,
@@ -330,7 +330,7 @@ function(object,
 		    tick = FALSE, labels = "")
 	
     if (length(var.label) > 1) {
-        text3d(cord.X[, 1] + 0.05, cord.X[, 2], cord.X[, 3] + 0.05, text = var.label,
+        text3d(cord.X[, 1] + 0.05, cord.X[, 2], cord.X[, 3] + 0.05, texts = var.label,
                color = col[[1]], font = font[1], cex = cex[1])
     }
 	
@@ -338,9 +338,9 @@ function(object,
 	
     if (any(axes.box == "axes") || any(axes.box == "all")) { 
         if (any(label.axes.box == "axes") || any(label.axes.box == "both")) {	
-            text3d(1.2, -0.05, 0, text = xlab, cex = 0.8, color = "black")
-            text3d(0, 1.27, 0, text = ylab, cex = 0.8, color = "black")
-            text3d(0, -0.05, 1.2, text = zlab, cex = 0.8, color = "black")
+            text3d(1.2, -0.05, 0, texts = xlab, cex = 0.8, color = "black")
+            text3d(0, 1.27, 0, texts = ylab, cex = 0.8, color = "black")
+            text3d(0, -0.05, 1.2, texts = zlab, cex = 0.8, color = "black")
 		}
 		
         x =	c(1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09,  1.09,
@@ -533,21 +533,21 @@ function(object,
 		    tick = FALSE, labels = "")
 	
     if (length(X.label) > 1) {
-        text3d(cord.X[, 1] + 0.05, cord.X[, 2], cord.X[, 3] + 0.05, text = X.label,
+        text3d(cord.X[, 1] + 0.05, cord.X[, 2], cord.X[, 3] + 0.05, texts = X.label,
                color = col[[1]], font = font[1], cex = cex[1])
     }
 	
     if (length(Y.label) > 1) {
-        text3d(cord.Y[, 1] + 0.05, cord.Y[, 2], cord.Y[, 3] + 0.05, text = Y.label,
+        text3d(cord.Y[, 1] + 0.05, cord.Y[, 2], cord.Y[, 3] + 0.05, texts = Y.label,
                color = col[[2]], font = font[2], cex = cex[2])
     }
 	par3d(cex = 0.8)	
 	
     if (any(axes.box == "axes") || any(axes.box == "all")) { 
         if (any(label.axes.box == "axes") || any(label.axes.box == "both")) {	
-            text3d(1.2, -0.05, 0, text = xlab, cex = 0.8, color = "black")
-            text3d(0, 1.27, 0, text = ylab, cex = 0.8, color = "black")
-            text3d(0, -0.05, 1.2, text = zlab, cex = 0.8, color = "black")
+            text3d(1.2, -0.05, 0, texts = xlab, cex = 0.8, color = "black")
+            text3d(0, 1.27, 0, texts = ylab, cex = 0.8, color = "black")
+            text3d(0, -0.05, 1.2, texts = zlab, cex = 0.8, color = "black")
 		}
 		
         x =	c(1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09,  1.09,
@@ -731,7 +731,7 @@ function(object,
 		    tick = FALSE, labels = "")
 	
     if (length(var.label) > 1) {
-        text3d(cord.X[, 1] + 0.05, cord.X[, 2], cord.X[, 3] + 0.05, text = var.label,
+        text3d(cord.X[, 1] + 0.05, cord.X[, 2], cord.X[, 3] + 0.05, texts = var.label,
                color = col[[1]], font = font[1], cex = cex[1])
     }
 	
@@ -739,9 +739,9 @@ function(object,
 	
     if (any(axes.box == "axes") || any(axes.box == "all")) { 
         if (any(label.axes.box == "axes") || any(label.axes.box == "both")) {	
-            text3d(1.2, -0.05, 0, text = xlab, cex = 0.8, color = "black")
-            text3d(0, 1.27, 0, text = ylab, cex = 0.8, color = "black")
-            text3d(0, -0.05, 1.2, text = zlab, cex = 0.8, color = "black")
+            text3d(1.2, -0.05, 0, texts = xlab, cex = 0.8, color = "black")
+            text3d(0, 1.27, 0, texts = ylab, cex = 0.8, color = "black")
+            text3d(0, -0.05, 1.2, texts = zlab, cex = 0.8, color = "black")
 		}
 		
         x =	c(1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09,  1.09,
@@ -960,21 +960,21 @@ function(object,
 		    tick = FALSE, labels = "")
 	
     if (length(X.label) > 1) {
-        text3d(cord.X[, 1] + 0.05, cord.X[, 2], cord.X[, 3] + 0.05, text = X.label,
+        text3d(cord.X[, 1] + 0.05, cord.X[, 2], cord.X[, 3] + 0.05, texts = X.label,
                color = col[[1]], font = font[1], cex = cex[1])
     }
 	
     if (length(Y.label) > 1) {
-        text3d(cord.Y[, 1] + 0.05, cord.Y[, 2], cord.Y[, 3] + 0.05, text = Y.label,
+        text3d(cord.Y[, 1] + 0.05, cord.Y[, 2], cord.Y[, 3] + 0.05, texts = Y.label,
                color = col[[2]], font = font[2], cex = cex[2])
     }
 	par3d(cex = 0.8)	
 	
     if (any(axes.box == "axes") || any(axes.box == "all")) { 
         if (any(label.axes.box == "axes") || any(label.axes.box == "both")) {	
-            text3d(1.2, -0.05, 0, text = xlab, cex = 0.8, color = "black")
-            text3d(0, 1.27, 0, text = ylab, cex = 0.8, color = "black")
-            text3d(0, -0.05, 1.2, text = zlab, cex = 0.8, color = "black")
+            text3d(1.2, -0.05, 0, texts = xlab, cex = 0.8, color = "black")
+            text3d(0, 1.27, 0, texts = ylab, cex = 0.8, color = "black")
+            text3d(0, -0.05, 1.2, texts = zlab, cex = 0.8, color = "black")
 		}
 		
         x =	c(1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09,  1.09,
@@ -1136,7 +1136,7 @@ function(object,
 		    tick = FALSE, labels = "")
 	
     if (length(var.label) > 1) {
-        text3d(cord.X[, 1], cord.X[, 2], cord.X[, 3], text = var.label,
+        text3d(cord.X[, 1], cord.X[, 2], cord.X[, 3], texts = var.label,
                color = col, font = font, cex = cex)
     }
 	
@@ -1144,9 +1144,9 @@ function(object,
 	
     if (any(axes.box == "axes") || any(axes.box == "all")) { 
         if (any(label.axes.box == "axes") || any(label.axes.box == "both")) {	
-            text3d(1.2, -0.05, 0, text = xlab, cex = 0.8, color = "black")
-            text3d(0, 1.27, 0, text = ylab, cex = 0.8, color = "black")
-            text3d(0, -0.05, 1.2, text = zlab, cex = 0.8, color = "black")
+            text3d(1.2, -0.05, 0, texts = xlab, cex = 0.8, color = "black")
+            text3d(0, 1.27, 0, texts = ylab, cex = 0.8, color = "black")
+            text3d(0, -0.05, 1.2, texts = zlab, cex = 0.8, color = "black")
 		}
 		
         x =	c(1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09,  1.09,
@@ -1319,7 +1319,7 @@ function(object,
 		    tick = FALSE, labels = "")
 	
     if (length(var.label) > 1) {
-        text3d(cord.X[, 1] + 0.05, cord.X[, 2], cord.X[, 3] + 0.05, text = var.label,
+        text3d(cord.X[, 1] + 0.05, cord.X[, 2], cord.X[, 3] + 0.05, texts = var.label,
                color = col[[1]], font = font[1], cex = cex[1])
     }
 	
@@ -1327,9 +1327,9 @@ function(object,
 	
     if (any(axes.box == "axes") || any(axes.box == "all")) { 
         if (any(label.axes.box == "axes") || any(label.axes.box == "both")) {	
-            text3d(1.2, -0.05, 0, text = xlab, cex = 0.8, color = "black")
-            text3d(0, 1.27, 0, text = ylab, cex = 0.8, color = "black")
-            text3d(0, -0.05, 1.2, text = zlab, cex = 0.8, color = "black")
+            text3d(1.2, -0.05, 0, texts = xlab, cex = 0.8, color = "black")
+            text3d(0, 1.27, 0, texts = ylab, cex = 0.8, color = "black")
+            text3d(0, -0.05, 1.2, texts = zlab, cex = 0.8, color = "black")
 		}
 		
         x =	c(1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09,  1.09,
@@ -1400,3 +1400,343 @@ function(object,
     return(invisible(list(coord.X = cord.X)))	
 }
 
+
+# ------------------------------ IPCA object ------------------------------------
+plot3dVar.ipca <-
+function(object, 
+         comp = 1:3, 
+	     rad.in = 1, 
+         var.label = FALSE, 
+         pch = NULL, 
+         cex = NULL, 
+         col = NULL, 
+         font = NULL,
+         axes.box = "all", 
+         label.axes.box = "both",		
+         xlab = NULL, 
+         ylab = NULL, 
+         zlab = NULL,		 
+         ...) 
+{
+
+
+    # validation des arguments #
+    #--------------------------#
+    if (length(comp) != 3)
+        stop("'comp' must be a numeric vector of length 3.")
+
+    if (!is.numeric(comp) || any(comp < 1))
+        stop("invalid vector for 'comp'.")
+
+    p = ncol(object$loadings)
+	q = nrow(object$loadings)
+	
+    if (any(comp > p)) 
+        stop("the elements of 'comp' must be smaller or equal than ", p, ".")
+
+    comp = round(comp)
+	
+    # calcul des coordonnées #
+    #------------------------#
+    cord.X = object$loadings[, comp] 
+
+    # le plot des variables #
+    #-----------------------#
+    pch.type = c("s", "t", "c", "o", "i", "d")
+    pch.name = c("sphere", "tetra", "cube", "octa", "icosa", "dodeca")
+
+    if (is.null(pch)) pch = "s"
+    if (is.null(cex)) cex = 1
+    if (is.null(col)) col = rep("blue", q)
+    if (is.null(font)) font = 2
+    if (is.logical(var.label)) {
+        if (isTRUE(var.label)) var.label = rownames(object$loadings)
+    }
+	
+	if (length(var.label) > 1) {
+        if (length(var.label) != q)
+            stop("'var.label' must be a character vector of length ", q, ".")
+    }
+
+    if (is.null(xlab)) xlab = paste("Comp ", comp[1])
+	if (is.null(ylab)) ylab = paste("Comp ", comp[2])
+	if (is.null(zlab)) zlab = paste("Comp ", comp[3])
+
+    # le plot 3d #
+    #------------#
+    opw = open3d(windowRect = c(500, 30, 1100, 630))
+	par3d(userMatrix = rotationMatrix(pi/80, 1, -1/(100*pi), 0))
+	
+    MaxAbs = max(abs(cord.X))
+    tickmark = round(seq(-MaxAbs, MaxAbs, length = 5), 2)
+    tick = seq(-1, 1, length = 5)	
+    cord.X = cord.X / MaxAbs
+
+    if (any(axes.box == "axes") || any(axes.box == "all"))
+        axes3d(c('x','y','z'), pos = c(0, 0, 0), nticks = 2, at = c(-1.2, 1.2), 
+		    tick = FALSE, labels = "")
+	
+    if (length(var.label) > 1) {
+        text3d(cord.X[, 1], cord.X[, 2], cord.X[, 3], texts = var.label,
+               color = col, font = font, cex = cex)
+    }
+	
+	par3d(cex = 0.8)	
+	
+    if (any(axes.box == "axes") || any(axes.box == "all")) { 
+        if (any(label.axes.box == "axes") || any(label.axes.box == "both")) {	
+            text3d(1.2, -0.05, 0, texts = xlab, cex = 0.8, color = "black")
+            text3d(0, 1.27, 0, texts = ylab, cex = 0.8, color = "black")
+            text3d(0, -0.05, 1.2, texts = zlab, cex = 0.8, color = "black")
+		}
+		
+        x =	c(1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09,  1.09,
+	          0.0, 0.0,  0.0, 0.0, 0.035, -0.035, 0.0, 0.035*sin(pi/4), -0.035*sin(pi/4), 0.0, 0.035*sin(pi/4), -0.035*sin(pi/4),
+              0.0, 0.0,  0.0, 0.0, 0.0,  0.0, 0.0, 0.035, -0.035, 0.0, 0.035*sin(pi/4), -0.035*sin(pi/4))
+	  
+        y = c(0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.035, -0.035, 0.0, 0.035*sin(pi/4), -0.035*sin(pi/4),
+              1.2, 1.09,  1.09, 1.2, 1.09,  1.09, 1.2, 1.09,  1.09, 1.2, 1.09,  1.09,
+	          0.0, 0.035, -0.035, 0.0, 0.0,  0.0, 0.0, 0.035*sin(pi/4), -0.035*sin(pi/4), 0.0, -0.035*sin(pi/4), 0.035*sin(pi/4))
+	  
+        z = c(0.0, 0.035, -0.035, 0.0, 0.035, -0.035, 0.0, 0.0,  0.0, 0.0, 0.035*sin(pi/4), -0.035*sin(pi/4),
+              0.0, 0.035, -0.035, 0.0, 0.0,  0.0, 0.0, 0.035*sin(pi/4), -0.035*sin(pi/4), 0.0, -0.035*sin(pi/4), 0.035*sin(pi/4),
+	          1.2, 1.09,  1.09, 1.2, 1.09,  1.09, 1.2, 1.09,  1.09, 1.2, 1.09,  1.09)	  
+
+        triangles3d(x = x, y = y, z = z, col = "black")
+    }
+	
+    points3d(1.2, 0, 0, size = 0.1, alpha = 0)	
+	points3d(0, 1.2, 0, size = 0.1, alpha = 0)
+	points3d(0, 0, 1.2, size = 0.1, alpha = 0)
+    points3d(-1.2, 0, 0, size = 0.1, alpha = 0)	
+	points3d(0, -1.2, 0, size = 0.1, alpha = 0)
+	points3d(0, 0, -1.2, size = 0.1, alpha = 0)
+	
+	cex = 1.5 * cex	
+
+    if (length(var.label) == 1) {
+        switch(pch.name[which(pch.type == pch)], 
+            sphere = plot3d(x = cord.X[, 1], y = cord.X[, 2], z = cord.X[, 3], type = "s", 
+                            col = col, radius = cex/50, add = TRUE),
+            tetra = shapelist3d(tetrahedron3d(), x = cord.X[, 1], y = cord.X[, 2], z = cord.X[, 3], 
+                            col = col, size = cex/65),
+            cube = shapelist3d(cube3d(), x = cord.X[, 1], y = cord.X[, 2], z = cord.X[, 3], 
+                            col = col, size = cex/70),
+            octa = shapelist3d(octahedron3d(), x = cord.X[, 1], y = cord.X[, 2], z = cord.X[, 3], 
+                            col = col, size = cex/35),
+            icosa = shapelist3d(icosahedron3d(), x = cord.X[, 1], y = cord.X[, 2], z = cord.X[, 3], 
+                            col = col, size = cex/50),
+            dodeca = shapelist3d(dodecahedron3d(), x = cord.X[, 1], y = cord.X[, 2], z = cord.X[, 3], 
+                            col = col, size = cex/50))
+    }
+
+    spheres3d(0, 0, 0, radius = rad.in, front = "fill", back = "fill", emission = gray(0.9), alpha = 0.6)
+	spheres3d(0, 0, 0, radius = rad.in, front = "line", back = "line", emission = gray(0.9))
+
+
+    if (any(axes.box == "box") || any(axes.box == "all")) {
+        axes3d(marklen = 25, xat = tick, yat = tick, zat = tick,
+               xlab = tickmark, ylab = tickmark, zlab = tickmark)
+        box3d()
+		if (any(label.axes.box == "box") || any(label.axes.box == "both")) {
+            mtext3d(xlab, "x-+", line = 1)
+            mtext3d(ylab, "y-+", line = 1.5)
+            mtext3d(zlab, "z+-", line = 1)
+        }
+    }
+	
+    if (any(axes.box == "bbox") || any(axes.box == "all")) {
+        bbox3d(color = c("#333377", "black"), emission = gray(0.5),
+               xat = tick, yat = tick, zat = tick,		
+               xlab = tickmark, ylab = tickmark, zlab = tickmark, 
+               specular = gray(0.1), shininess = 5, alpha = 0.8, marklen = 25) 
+        if (any(label.axes.box == "box") || any(label.axes.box == "both")) {
+            mtext3d(xlab, "x-+", line = 1)
+            mtext3d(ylab, "y-+", line = 1.5)
+            mtext3d(zlab, "z+-", line = 1)
+        }
+    }
+
+    title3d(...)	
+    return(invisible(list(coord.X = cord.X)))
+}
+
+
+# ----------------------------- sIPCA---------------------------------------------
+plot3dVar.sipca <- 
+function(object, 
+         comp = 1:3, 
+         rad.in = 1, 
+         var.label = FALSE, 
+         pch = NULL, 
+         cex = NULL, 
+         col = NULL, 
+         font = NULL, 
+         axes.box = "all", 
+         label.axes.box = "both",		
+         xlab = NULL, 
+         ylab = NULL, 
+         zlab = NULL, 
+         ...)
+{
+
+    # validation des arguments #
+    #--------------------------#
+    if (length(comp) != 3)
+        stop("'comp' must be a numeric vector of length 3.")
+
+    if (!is.numeric(comp) || any(comp < 1))
+        stop("invalid vector for 'comp'.")
+
+    if (any(comp > object$ncomp)) 
+        stop("the elements of 'comp' must be smaller or equal than ", object$ncomp, ".")
+
+    comp = round(comp)	
+
+    # calcul des coordonnées #
+    #------------------------#
+    keep.X = apply(abs(object$loadings), 1, sum) > 0
+    cord.X = cor(object$X[, keep.X], object$x[, comp], use = "pairwise")
+
+    p = ncol(object$X)
+
+    # le plot des variables #
+    #-----------------------#
+    pch.type = matrix(1:6, ncol = 6)
+    colnames(pch.type) = c("s", "t", "c", "o", "i", "d")
+    pch.name = c("sphere", "tetra", "cube", "octa", "icosa", "dodeca")
+	
+    if (length(var.label) > 1 & length(var.label) != p)
+        stop("'var.label' must be a vector of length 'ncol(X)' or a boolean atomic vector.")
+
+   if (is.null(pch)) {
+        pch = c("s")
+    }
+
+    if (is.null(cex)) {
+        cex = c(1)
+    }
+
+    if (is.null(col)) {
+        col = list(rep("red", p))
+    }
+    else {
+        if (is.list(col)) {
+            if (length(col[[1]]) != p) 
+                stop("'col' must be a vector of length 1 or a vector of length ", p)
+        }
+        else { 
+            if (length(col) == 1) { 
+                col = list(rep(col[1], p))
+            }
+            else {
+                stop("'col' must be a vector of length 1 or a vector of length ", p)
+            }
+        }
+    }
+
+    if (is.null(font)) {
+        font = c(2)
+    }
+
+      col[[1]] = col[[1]][keep.X]
+
+    if (var.label) var.label = object$names$X
+
+      if (length(var.label) == p) var.label = var.label[keep.X]
+
+    if (is.null(xlab)) xlab = paste("Comp ", comp[1])
+	if (is.null(ylab)) ylab = paste("Comp ", comp[2])
+	if (is.null(zlab)) zlab = paste("Comp ", comp[3])
+
+    # le plot 3d #
+    #------------#
+    opw = open3d(windowRect = c(500, 30, 1100, 630))
+     
+	par3d(userMatrix = rotationMatrix(pi/80, 1, -1/(100*pi), 0))
+	
+    if (any(axes.box == "axes") || any(axes.box == "all"))
+        axes3d(c('x','y','z'), pos = c(0, 0, 0), nticks = 2, at = c(-1.2, 1.2), 
+		    tick = FALSE, labels = "")
+	
+    if (length(var.label) > 1) {
+        text3d(cord.X[, 1] + 0.05, cord.X[, 2], cord.X[, 3] + 0.05, texts = var.label,
+               color = col[[1]], font = font[1], cex = cex[1])
+    }
+	
+	par3d(cex = 0.8)	
+	
+    if (any(axes.box == "axes") || any(axes.box == "all")) { 
+        if (any(label.axes.box == "axes") || any(label.axes.box == "both")) {	
+            text3d(1.2, -0.05, 0, texts = xlab, cex = 0.8, color = "black")
+            text3d(0, 1.27, 0, texts = ylab, cex = 0.8, color = "black")
+            text3d(0, -0.05, 1.2, texts = zlab, cex = 0.8, color = "black")
+		}
+		
+        x =	c(1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09, 1.09, 1.2, 1.09,  1.09,
+	          0.0, 0.0,  0.0, 0.0, 0.035, -0.035, 0.0, 0.035*sin(pi/4), -0.035*sin(pi/4), 0.0, 0.035*sin(pi/4), -0.035*sin(pi/4),
+              0.0, 0.0,  0.0, 0.0, 0.0,  0.0, 0.0, 0.035, -0.035, 0.0, 0.035*sin(pi/4), -0.035*sin(pi/4))
+	  
+        y = c(0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.035, -0.035, 0.0, 0.035*sin(pi/4), -0.035*sin(pi/4),
+              1.2, 1.09,  1.09, 1.2, 1.09,  1.09, 1.2, 1.09,  1.09, 1.2, 1.09,  1.09,
+	          0.0, 0.035, -0.035, 0.0, 0.0,  0.0, 0.0, 0.035*sin(pi/4), -0.035*sin(pi/4), 0.0, -0.035*sin(pi/4), 0.035*sin(pi/4))
+	  
+        z = c(0.0, 0.035, -0.035, 0.0, 0.035, -0.035, 0.0, 0.0,  0.0, 0.0, 0.035*sin(pi/4), -0.035*sin(pi/4),
+              0.0, 0.035, -0.035, 0.0, 0.0,  0.0, 0.0, 0.035*sin(pi/4), -0.035*sin(pi/4), 0.0, -0.035*sin(pi/4), 0.035*sin(pi/4),
+	          1.2, 1.09,  1.09, 1.2, 1.09,  1.09, 1.2, 1.09,  1.09, 1.2, 1.09,  1.09)	  
+
+        triangles3d(x = x, y = y, z = z, col = "black")
+    }
+	
+    points3d(1.2, 0, 0, size = 0.1, alpha = 0)	
+	points3d(0, 1.2, 0, size = 0.1, alpha = 0)
+	points3d(0, 0, 1.2, size = 0.1, alpha = 0)
+    points3d(-1.2, 0, 0, size = 0.1, alpha = 0)	
+	points3d(0, -1.2, 0, size = 0.1, alpha = 0)
+	points3d(0, 0, -1.2, size = 0.1, alpha = 0)
+	
+	cex = 1.5*cex	
+	
+    if (length(var.label) == 1) {
+        switch(pch.name[pch.type[, pch[1]]], 
+            sphere = plot3d(x = cord.X[, 1], y = cord.X[, 2], z = cord.X[, 3], type = "s", 
+                            col = col[[1]], radius = cex[1]/50, add = TRUE),
+            tetra = shapelist3d(tetrahedron3d(), x = cord.X[, 1], y = cord.X[, 2], z = cord.X[, 3], 
+                            col = col[[1]], size = cex[1]/65),
+            cube = shapelist3d(cube3d(), x = cord.X[, 1], y = cord.X[, 2], z = cord.X[, 3], 
+                            col = col[[1]], size = cex[1]/70),
+            octa = shapelist3d(octahedron3d(), x = cord.X[, 1], y = cord.X[, 2], z = cord.X[, 3], 
+                            col = col[[1]], size = cex[1]/35),
+            icosa = shapelist3d(icosahedron3d(), x = cord.X[, 1], y = cord.X[, 2], z = cord.X[, 3], 
+                            col = col[[1]], size = cex[1]/50),
+            dodeca = shapelist3d(dodecahedron3d(), x = cord.X[, 1], y = cord.X[, 2], z = cord.X[, 3], 
+                            col = col[[1]], size = cex[1]/50))
+    }
+   
+	
+    spheres3d(0, 0, 0, radius = rad.in, front = "fill", back = "fill", emission = gray(0.9), alpha = 0.6)
+	spheres3d(0, 0, 0, radius = rad.in, front = "line", back = "line", emission = gray(0.9))
+	
+    if (any(axes.box == "box") || any(axes.box == "all")) {
+        axes3d(marklen = 25)
+        box3d()
+		if (any(label.axes.box == "box") || any(label.axes.box == "both")) {
+            mtext3d(xlab, "x-+", line = 1)
+            mtext3d(ylab, "y-+", line = 1.5)
+            mtext3d(zlab, "z+-", line = 1)
+        }
+    }
+	
+    if (any(axes.box == "bbox") || any(axes.box == "all")) {
+        bbox3d(color = c("#333377", "black"), emission = gray(0.5), 
+               specular = gray(0.1), shininess = 5, alpha = 0.8, marklen = 25) 
+        if (any(label.axes.box == "box") || any(label.axes.box == "both")) {
+            mtext3d(xlab, "x-+", line = 1)
+            mtext3d(ylab, "y-+", line = 1.5)
+            mtext3d(zlab, "z+-", line = 1)
+        }
+    }
+
+    title3d(...)
+    return(invisible(list(coord.X = cord.X)))	
+}
\ No newline at end of file
